==> hyades.source_3.2.0_20041221_1637.zip: org/eclipse/hyades/log/ui/internal/util/SearchRecordDialog.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

package org.eclipse.hyades.log.ui.internal.util;


import java.util.List;
import java.util.Locale;

import org.eclipse.hyades.log.ui.internal.LogUIPlugin;
import org.eclipse.hyades.log.ui.internal.actions.provider.ILogFindProvider;
import org.eclipse.hyades.models.hierarchy.util.IFilterElement;
import org.eclipse.hyades.security.util.GridUtil;
import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Tree;
import org.eclipse.ui.help.WorkbenchHelp;

public class SearchRecordDialog extends Dialog implements SelectionListener
{
	private CBEAdvFilterUI _filters;
	private Button btnFind;
	private Button btnCancel;
	private Button btnUp;
	private Button btnDown;
	private Label lblMessage;
	private Tree tree;
	private java.lang.String _title;
	private ILogFindProvider logFindProvider = null;
	
	public SearchRecordDialog(Shell shell, String windowTitle, Image windowImage, ILogFindProvider logFindProvider) {
		super(shell);
		_title = windowTitle;
		setDefaultImage(windowImage);
		this.logFindProvider = logFindProvider;
	}

	protected void configureShell(Shell shell) {
		super.configureShell(shell);
		shell.setText(_title);
	}

	protected Control createContents(Composite parent) {
		Composite c = new Composite(parent, SWT.NONE);

		GridLayout layout;
		GridData data;

		layout = new GridLayout();
		layout.numColumns = 1;
		layout.verticalSpacing = 0;
		c.setLayout(layout);
		data = GridUtil.createFill();
		/* If width is specified, text gets cut out
		 * when font is larger. Bug #61460
		 */ 
		//data.widthHint = 500;
		c.setLayoutData(data);

		_filters =  new CBEAdvFilterUI(LogUIConstants.SEARCH);
		_filters.createControl(c,LogUIPlugin.getResourceString("STR_FIND_CONTENT_LABEL"));
//		initializeFilters();

		Label hLine = new Label(c,SWT.SEPARATOR  | SWT.HORIZONTAL);
		data = new GridData(GridData.FILL_HORIZONTAL);
		hLine.setLayoutData(data);
		
		Composite b = new Composite(c,SWT.NONE);
		layout = new GridLayout();
		layout.numColumns = 2;
		layout.verticalSpacing = 0;
		b.setLayout(layout);
		data = GridUtil.createFill();
		b.setLayoutData(data);

		createOptionsGroup(b);
		createButtonsGroup(b);
		createFooter(c);
		
//		initializeButtons();
		initializeFiltersAndButtons();
		
		btnFind.addSelectionListener(this);
		btnCancel.addSelectionListener(this);
		_filters.getAddBtn().addSelectionListener(this);
		_filters.getRemoveBtn().addSelectionListener(this);
		
		WorkbenchHelp.setHelp(c, ContextIds.ACTLOG_VIEW_DIALOG_SEARCH);
		WorkbenchHelp.setHelp(btnUp, ContextIds.ACTLOG_VIEW_DIALOG_SEARCH_UP);
		WorkbenchHelp.setHelp(btnDown, ContextIds.ACTLOG_VIEW_DIALOG_SEARCH_DOWN);

		return c;
	}
	
	private void initializeFiltersAndButtons() {
		if (logFindProvider!=null) {
			String filters = logFindProvider.loadFindPreferenceString();
			_filters.initializeFilters(filters);
			
			if (logFindProvider.loadFindDirection())
			{
				btnDown.setSelection(true);
			}
			else
			{
				btnUp.setSelection(true);
			}
			btnFind.setEnabled(_filters.getFilterList().getFilters().size()>0);
		}
	}
	
//	private void initializeButtons() {
//		if (LogUIPlugin.getDefault().getPreferenceStore().getString(LogUIConstants.PD_SEARCH_DIRECTION_OPTIONS).equals("1"))
//		{		btnDown.setSelection(true); } 
//		else
//		{ btnUp.setSelection(true); }
//		btnFind.setEnabled(_filters.getFilterList().getFilters().size()>0);
//	}
	
	private void createOptionsGroup(Composite c){

			Composite options = new Composite(c, SWT.NONE);
			GridLayout layout = new GridLayout();
			layout.numColumns = 1;
			options.setLayout(layout);
			options.setLayoutData(GridUtil.createHorizontalFill());
			
			Group direction = new Group(options, SWT.NONE);
			layout = new GridLayout();
			
			layout.numColumns = 2;
			
			direction.setText(LogUIPlugin.getResourceString("STR_DIRECTION_LABEL"));
			direction.setLayout(layout);
			GridData data =  new GridData(GridData.FILL_HORIZONTAL);
			data.horizontalAlignment = GridData.BEGINNING;
			data.widthHint = 300;
			direction.setLayoutData(data);
			btnUp = new Button(direction, SWT.RADIO);
			btnUp.setText(LogUIPlugin.getResourceString("STR_DIR_UP_LABEL"));
			btnDown = new Button(direction, SWT.RADIO);
			btnDown.setText(LogUIPlugin.getResourceString("STR_DIR_DOWN_LABEL"));
//			btnDown.setSelection(true);
	}
	
	private void createButtonsGroup(Composite c){

			Composite buttons = new Composite(c, SWT.NONE);
			GridLayout layout = new GridLayout();
			layout.numColumns = 2;
			GridData data = GridUtil.createHorizontalFill();
			data.horizontalAlignment = GridData.END;
			buttons.setLayout(layout);
			buttons.setLayoutData(data);

			btnFind = new Button(buttons, SWT.PUSH);
			btnFind.setText(LogUIPlugin.getResourceString("STR_FINDNEXT_LABEL"));
			data = new GridData();
			//Need wider button for Chinese, and PTBR translation of "Find Next", i.e. "Localizar Proxima".
			if (Locale.getDefault().toString().equals("en_US"))
				data.widthHint = 75;
			else
				data.widthHint = 100;
			btnFind.setLayoutData(data);

			btnCancel = new Button(buttons, SWT.PUSH);
			btnCancel.setText(LogUIPlugin.getResourceString("STR_CANCEL_LABEL"));
			data = new GridData();
			//Need wider button for Chinese, and PTBR translation of "Find Next", i.e. "Localizar Proxima".
			if (Locale.getDefault().toString().equals("en_US"))
				data.widthHint = 75;
			else
				data.widthHint = 100;
			btnCancel.setLayoutData(data);

			// set the dialog's default button 
			Shell shell = c.getShell();
			if (shell != null) {
				shell.setDefaultButton(btnFind);
			}

//			btnFind.setEnabled(false);
	}
	
	private void createFooter(Composite c){
		lblMessage = new Label(c, SWT.NONE);
		GridData data = new GridData(GridData.FILL_HORIZONTAL);
		data.horizontalSpan = 2;
		lblMessage.setLayoutData(data);
	}

	public void updateMessage(String message){
		if(!lblMessage.isDisposed())
			lblMessage.setText(message);
	}
	public void widgetDefaultSelected(SelectionEvent e){
	}
	
	public void widgetSelected(SelectionEvent e){
		if(e.widget==btnCancel) {
			if (logFindProvider!=null)
			{
				LogFindCriteria criteria = new LogFindCriteria();
				List filters = _filters.getFilterList().getFilters();
				int s = filters.size();
				criteria.setFilters((IFilterElement[])filters.toArray(new IFilterElement[s]));
				criteria.setForwardDirection(btnDown.getSelection()?true:false);
				logFindProvider.storeFindOptions(criteria);
			}
			close();
		}
		
		if(e.widget==btnFind){
			lblMessage.setText("");	
			LogFindCriteria criteria = new LogFindCriteria();
			List filters = _filters.getFilterList().getFilters();
			int s = filters.size();
			criteria.setFilters((IFilterElement[])filters.toArray(new IFilterElement[s]));
			criteria.setForwardDirection(btnDown.getSelection()?true:false);
			
			if (logFindProvider!=null)
				logFindProvider.findRecord(criteria);
		}
		
		if (e.widget==_filters.getAddBtn()
			|| e.widget==_filters.getRemoveBtn()){
			btnFind.setEnabled(_filters.getFilterList().getSize()>0);
		}
			
	}	
}

==> hyades.source_3.3.0_20050623_2150.zip: org/eclipse/hyades/log/ui/internal/util/SearchRecordDialog.java <==
/**********************************************************************
 * Copyright (c) 2005 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * $Id: SearchRecordDialog.java,v 1.13 2005/04/26 16:20:46 ewchan Exp $
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

package org.eclipse.hyades.log.ui.internal.util;


import java.util.List;

import org.eclipse.hyades.log.ui.internal.LogUIPlugin;
import org.eclipse.hyades.log.ui.internal.actions.provider.ILogFindProvider;
import org.eclipse.hyades.models.hierarchy.util.IFilterElement;
import org.eclipse.hyades.security.util.GridUtil;
import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Tree;
import org.eclipse.ui.help.WorkbenchHelp;

public class SearchRecordDialog extends Dialog implements SelectionListener
{
	private CBEAdvFilterUI _filters;
	private Button btnFind;
	private Button btnCancel;
	private Button btnUp;
	private Button btnDown;
	private Label lblMessage;
	private Tree tree;
	private java.lang.String _title;
	private ILogFindProvider logFindProvider = null;
	
	public SearchRecordDialog(Shell shell, String windowTitle, Image windowImage, ILogFindProvider logFindProvider) {
		super(shell);
		setShellStyle(SWT.RESIZE | SWT.BORDER | SWT.TITLE);				
		_title = windowTitle;
		setDefaultImage(windowImage);
		this.logFindProvider = logFindProvider;
	}

	protected void configureShell(Shell shell) {
		super.configureShell(shell);
		shell.setText(_title);
	}

	protected Control createContents(Composite parent) {
		Composite c = new Composite(parent, SWT.NONE);

		GridLayout layout;
		GridData data;

		layout = new GridLayout();
		layout.numColumns = 1;
		layout.verticalSpacing = 0;
		c.setLayout(layout);
		data = GridUtil.createFill();
		/* If width is specified, text gets cut out
		 * when font is larger. Bug #61460
		 */ 
		//data.widthHint = 500;
		c.setLayoutData(data);

		_filters =  new CBEAdvFilterUI(LogUIConstants.SEARCH, LogUIPlugin.getDefault().getPreferenceStore());
		_filters.createControl(c,LogUIPlugin.getResourceString("STR_FIND_CONTENT_LABEL"));
//		initializeFilters();

		Label hLine = new Label(c,SWT.SEPARATOR  | SWT.HORIZONTAL);
		data = new GridData(GridData.FILL_HORIZONTAL);
		hLine.setLayoutData(data);
		
		Composite b = new Composite(c,SWT.NONE);
		layout = new GridLayout();
		layout.numColumns = 2;
		layout.verticalSpacing = 0;
		b.setLayout(layout);
		data = GridUtil.createFill();
		b.setLayoutData(data);

		createOptionsGroup(b);
		createButtonsGroup(b);
		createFooter(c);
		
//		initializeButtons();
		initializeFiltersAndButtons();
		
		btnFind.addSelectionListener(this);
		btnCancel.addSelectionListener(this);
		_filters.getAddBtn().addSelectionListener(this);
		_filters.getRemoveBtn().addSelectionListener(this);
		
		WorkbenchHelp.setHelp(c, ContextIds.ACTLOG_VIEW_DIALOG_SEARCH);
		WorkbenchHelp.setHelp(btnUp, ContextIds.ACTLOG_VIEW_DIALOG_SEARCH_UP);
		WorkbenchHelp.setHelp(btnDown, ContextIds.ACTLOG_VIEW_DIALOG_SEARCH_DOWN);

		return c;
	}
	
	private void initializeFiltersAndButtons() {
		if (logFindProvider!=null) {
			String filters = logFindProvider.loadFindPreferenceString();
			_filters.initializeFilters(filters);
			
			if (logFindProvider.loadFindDirection())
			{
				btnDown.setSelection(true);
			}
			else
			{
				btnUp.setSelection(true);
			}
			btnFind.setEnabled(_filters.getFilterList().getFilters().size()>0);
		}
	}
	
//	private void initializeButtons() {
//		if (LogUIPlugin.getDefault().getPreferenceStore().getString(LogUIConstants.PD_SEARCH_DIRECTION_OPTIONS).equals("1"))
//		{		btnDown.setSelection(true); } 
//		else
//		{ btnUp.setSelection(true); }
//		btnFind.setEnabled(_filters.getFilterList().getFilters().size()>0);
//	}
	
	private void createOptionsGroup(Composite c){

			Composite options = new Composite(c, SWT.NONE);
			GridLayout layout = new GridLayout();
			layout.numColumns = 1;
			options.setLayout(layout);
			options.setLayoutData(GridUtil.createHorizontalFill());
			
			Group direction = new Group(options, SWT.NONE);
			layout = new GridLayout();
			
			layout.numColumns = 2;
			
			direction.setText(LogUIPlugin.getResourceString("STR_DIRECTION_LABEL"));
			direction.setLayout(layout);
			GridData data =  GridUtil.createHorizontalFill();
			data.horizontalAlignment = GridData.BEGINNING;
//			data.widthHint = 350;
			direction.setLayoutData(data);
			btnUp = new Button(direction, SWT.RADIO);
			btnUp.setText(LogUIPlugin.getResourceString("STR_DIR_UP_LABEL"));
			btnDown = new Button(direction, SWT.RADIO);
			btnDown.setText(LogUIPlugin.getResourceString("STR_DIR_DOWN_LABEL"));
//			btnDown.setSelection(true);
	}
	
	private void createButtonsGroup(Composite c){

			Composite buttons = new Composite(c, SWT.NONE);
			GridLayout layout = new GridLayout();
			layout.numColumns = 2;
			GridData data = GridUtil.createHorizontalFill();
			data.horizontalAlignment = GridData.END;
			buttons.setLayout(layout);
			buttons.setLayoutData(data);

			btnFind = new Button(buttons, SWT.PUSH);
			btnFind.setText(LogUIPlugin.getResourceString("STR_FINDNEXT_LABEL"));
			data = GridUtil.createHorizontalFill();
			btnFind.setLayoutData(data);

			btnCancel = new Button(buttons, SWT.PUSH);
			btnCancel.setText(LogUIPlugin.getResourceString("STR_CANCEL_LABEL"));
			data = GridUtil.createHorizontalFill();
			btnCancel.setLayoutData(data);

			// set the dialog's default button 
			Shell shell = c.getShell();
			if (shell != null) {
				shell.setDefaultButton(btnFind);
			}

//			btnFind.setEnabled(false);
	}
	
	private void createFooter(Composite c){
		lblMessage = new Label(c, SWT.NONE);
		GridData data = new GridData(GridData.FILL_HORIZONTAL);
		data.horizontalSpan = 2;
		lblMessage.setLayoutData(data);
	}

	public void updateMessage(String message){
		if(!lblMessage.isDisposed())
			lblMessage.setText(message);
	}
	public void widgetDefaultSelected(SelectionEvent e){
	}
	
	public void widgetSelected(SelectionEvent e){
		if(e.widget==btnCancel) {
			if (logFindProvider!=null)
			{
				LogFindCriteria criteria = new LogFindCriteria();
				List filters = _filters.getFilterList().getFilters();
				int s = filters.size();
				criteria.setFilters((IFilterElement[])filters.toArray(new IFilterElement[s]));
				criteria.setForwardDirection(btnDown.getSelection()?true:false);
				logFindProvider.storeFindOptions(criteria);
			}
			close();
		}
		
		if(e.widget==btnFind){
			lblMessage.setText("");	
			LogFindCriteria criteria = new LogFindCriteria();
			List filters = _filters.getFilterList().getFilters();
			int s = filters.size();
			criteria.setFilters((IFilterElement[])filters.toArray(new IFilterElement[s]));
			criteria.setForwardDirection(btnDown.getSelection()?true:false);
			
			if (logFindProvider!=null)
				logFindProvider.findRecord(criteria);
		}
		
		if (e.widget==_filters.getAddBtn()
			|| e.widget==_filters.getRemoveBtn()){
			btnFind.setEnabled(_filters.getFilterList().getSize()>0);
		}
			
	}	
}
